spoon.routing.NetMessage

Package spoon :: Package routing :: Class NetMessage |
[hide private]
[frames] | no frames]

# Class NetMessage

source code

    object --+
             |
            NetMessage

NetMessage is the protocol unit for the networking component of spoon. It contains a src (source node id), dest (destination node id), message type and an object attachment. The object attachment can of course be anything at all that's serializable. The message type indicates what subsystem the message should be handled by. Currently only messaging is implemented, but in the future, who knows.

To Do: At some point in the future I'd like to add an HMAC here, but I have to sort out how keys and such are shared at a protocol level here.

Instance Methods | [hide private]
`` | __init__(self, src=None, dst=None, mtype=None, attach=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, src=None, dst=None, mtype=None, attach=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)